==> zio-aws-ec2_2.12-5.17.125.1-sources.jar: zio/aws/ec2/model/ClientCertificateRevocationListStatus.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ClientCertificateRevocationListStatus(
    code: Option[zio.aws.ec2.model.ClientCertificateRevocationListStatusCode] =
      None,
    message: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ClientCertificateRevocationListStatus = {
    import ClientCertificateRevocationListStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ClientCertificateRevocationListStatus
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ClientCertificateRevocationListStatus.ReadOnly =
    zio.aws.ec2.model.ClientCertificateRevocationListStatus
      .wrap(buildAwsValue())
}
object ClientCertificateRevocationListStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ClientCertificateRevocationListStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ClientCertificateRevocationListStatus =
      zio.aws.ec2.model.ClientCertificateRevocationListStatus(
        code.map(value => value),
        message.map(value => value)
      )
    def code
        : Option[zio.aws.ec2.model.ClientCertificateRevocationListStatusCode]
    def message: Option[String]
    def getCode: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.ClientCertificateRevocationListStatusCode
    ] = AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ClientCertificateRevocationListStatus
  ) extends zio.aws.ec2.model.ClientCertificateRevocationListStatus.ReadOnly {
    override val code
        : Option[zio.aws.ec2.model.ClientCertificateRevocationListStatusCode] =
      scala
        .Option(impl.code())
        .map(value =>
          zio.aws.ec2.model.ClientCertificateRevocationListStatusCode
            .wrap(value)
        )
    override val message: Option[String] =
      scala.Option(impl.message()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ClientCertificateRevocationListStatus
  ): zio.aws.ec2.model.ClientCertificateRevocationListStatus.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-5.17.203.2-sources.jar: zio/aws/ec2/model/ClientCertificateRevocationListStatus.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ClientCertificateRevocationListStatus(
    code: Optional[
      zio.aws.ec2.model.ClientCertificateRevocationListStatusCode
    ] = Optional.Absent,
    message: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ClientCertificateRevocationListStatus = {
    import ClientCertificateRevocationListStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ClientCertificateRevocationListStatus
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ClientCertificateRevocationListStatus.ReadOnly =
    zio.aws.ec2.model.ClientCertificateRevocationListStatus
      .wrap(buildAwsValue())
}
object ClientCertificateRevocationListStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ClientCertificateRevocationListStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ClientCertificateRevocationListStatus =
      zio.aws.ec2.model.ClientCertificateRevocationListStatus(
        code.map(value => value),
        message.map(value => value)
      )
    def code
        : Optional[zio.aws.ec2.model.ClientCertificateRevocationListStatusCode]
    def message: Optional[String]
    def getCode: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.ClientCertificateRevocationListStatusCode
    ] = AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ClientCertificateRevocationListStatus
  ) extends zio.aws.ec2.model.ClientCertificateRevocationListStatus.ReadOnly {
    override val code: Optional[
      zio.aws.ec2.model.ClientCertificateRevocationListStatusCode
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.code())
      .map(value =>
        zio.aws.ec2.model.ClientCertificateRevocationListStatusCode.wrap(value)
      )
    override val message: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.message())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ClientCertificateRevocationListStatus
  ): zio.aws.ec2.model.ClientCertificateRevocationListStatus.ReadOnly =
    new Wrapper(impl)
}
